__version__ = "2.0.1"
__author__ = "vladislavkovalskyi"

WEATHER_API = "http://api.openweathermap.org/data/2.5/weather?"

WEATHER_CODES = {
    # Гроза
    200: "Гроза с небольшим дождём",
    201: "Гроза с дождём",
    202: "Гроза с сильным дождём",
    210: "Легкая гроза",
    211: "Гроза",
    212: "Сильная гроза",
    221: "Рваная гроза",
    230: "Гроза с мелким дождиком",
    231: "Гроза с моросью",
    232: "Гроза с сильным моросящим дождём",

    # Морось
    300: "Слабая морось",
    301: "Морось",
    302: "Сильный дождь",
    310: "Интенсивный свет и моросящий дождь",
    311: "Моросящий дождь",
    312: "Сильный моросящий дождь",
    313: "Ливень, дождь и изморось",
    314: "Сильный ливень, дождь и изморось",
    321: "Изморось",

    # Дождь
    500: "Легкий дождь",
    501: "Умеренный дождь",
    502: "Сильный дождь",
    503: "Очень сильный дождь",
    504: "Жёсткий дождь",
    511: "Холодный дождь",
    520: "Интенсивный свет и ливень",
    521: "Дождь как в душе",
    522: "Сильный ливневый дождь",
    531: "Рваный душ под дождем",

    # Снег
    600: "Легкий снег",
    601: "Снег",
    602: "Снегопад",
    611: "Мокрый снег",
    612: "Легкий дождь с мокрым снегом",
    613: "Мокрый снег",
    615: "Небольшой дождь и снег",
    616: "Дождь и снег",
    620: "Легкий снегопад",
    621: "Сильный снегопад",
    622: "Очень сильный снегопад",

    # Атмосфера
    701: "Утренний туман",
    711: "Дым",
    721: "Водный туман",
    731: "Песчано-пыльные вихри",
    741: "Ясный туман",
    751: "Песок",
    761: "Пыль",
    762: "Вулканический пепел",
    771: "Шквалы",
    781: "Торнадо",

    # Небо, облака
    800: "Чистое небо",
    801: "Очень мало облаков",
    802: "Мало облаков",
    803: "Облачно",
    804: "Сильно облачно",
}